@@ -98,7 +98,7 @@ translate.logistic_reg <- function(x, engine = x$engine, ...) {
         } else if (quo_get_expr(x$args$mixture) == 1) {
           arg_vals$type <- 6      ## lasso
         } else {
-          rlang::abort("For the LiblineaR engine, mixture must be 0 or 1.")
+          cli::cli_abort("For the LiblineaR engine, {.arg mixture} must be 0 or 1.")
         }
     }
     x$method$fit$args <- arg_vals
@@ -135,25 +135,32 @@ update.logistic_reg <-
 # ------------------------------------------------------------------------------
 
 #' @export
-check_args.logistic_reg <- function(object) {
+check_args.logistic_reg <- function(object, call = rlang::caller_env()) {
 
   args <- lapply(object$args, rlang::eval_tidy)
 
-  if (all(is.numeric(args$penalty)) && any(args$penalty < 0))
-    rlang::abort("The amount of regularization should be >= 0.")
-  if (is.numeric(args$mixture) && (args$mixture < 0 | args$mixture > 1))
-    rlang::abort("The mixture proportion should be within [0,1].")
-  if (is.numeric(args$mixture) && length(args$mixture) > 1)
-    rlang::abort("Only one value of `mixture` is allowed.")
+  check_number_decimal(args$mixture, min = 0, max = 1, allow_null = TRUE, call = call, arg = "mixture")
+  check_number_decimal(args$penalty, min = 0, allow_null = TRUE, call = call, arg = "penalty")
 
   if (object$engine == "LiblineaR") {
-    if(is.numeric(args$mixture) && !args$mixture %in% 0:1)
-      rlang::abort(c("For the LiblineaR engine, mixture must be 0 or 1.",
-                     "Choose a pure ridge model with `mixture = 0`.",
-                     "Choose a pure lasso model with `mixture = 1`.",
-                     "The Liblinear engine does not support other values."))
-    if(all(is.numeric(args$penalty)) && !all(args$penalty > 0))
-      rlang::abort("For the LiblineaR engine, penalty must be > 0.")
+    if (is.numeric(args$mixture) && !args$mixture %in% 0:1) {
+      cli::cli_abort(
+        c("x" = "For the {.pkg LiblineaR} engine, mixture must be 0 or 1, \\
+                not {args$mixture}.",
+          "i" = "Choose a pure ridge model with {.code mixture = 0} or \\
+                a pure lasso model with {.code mixture = 1}.",
+          "!" = "The {.pkg Liblinear} engine does not support other values."),
+        call = call
+      )
+    }
+
+    if ((!is.null(args$penalty)) && args$penalty == 0) {
+      cli::cli_abort(
+        "For the {.pkg LiblineaR} engine, {.arg penalty} must be {.code > 0}, \\
+         not 0.",
+        call = call
+      )
+    }
   }
 
   invisible(object)
