@@ -120,7 +120,7 @@ check_args.mars <- function(object, call = rlang::caller_env()) {
 
 earth_submodel_pred <- function(object, new_data, terms = 2:3, ...) {
   load_libs(object, quiet = TRUE, attach = TRUE)
-  map(terms, earth_reg_updater, object = object, newdata = new_data, ...) %>%
+  map(terms, earth_reg_updater, object = object, newdata = new_data, ...) |>
     purrr::list_rbind()
 }
 
@@ -182,7 +182,7 @@ multi_predict._earth <-
 
     res <-
       map(num_terms, earth_by_terms, object = object,
-          new_data = new_data, type = type, ...) %>%
+          new_data = new_data, type = type, ...) |>
       purrr::list_rbind()
     res <- arrange(res, .row, num_terms)
     res <- split(res[, -1], res$.row)
