@@ -379,43 +379,6 @@ set_model_arg(
   has_submodel = FALSE
 )
 
-set_model_arg(
-  model = "multinom_reg",
-  eng = "brulee",
-  parsnip = "epochs",
-  original = "epochs",
-  func = list(pkg = "dials", fun = "epochs"),
-  has_submodel = FALSE
-)
-
-set_model_arg(
-  model = "multinom_reg",
-  eng = "brulee",
-  parsnip = "learn_rate",
-  original = "learn_rate",
-  func = list(pkg = "dials", fun = "learn_rate"),
-  has_submodel = FALSE
-)
-
-set_model_arg(
-  model = "multinom_reg",
-  eng = "brulee",
-  parsnip = "momentum",
-  original = "momentum",
-  func = list(pkg = "dials", fun = "momentum"),
-  has_submodel = FALSE
-)
-
-
-set_model_arg(
-  model = "multinom_reg",
-  eng = "brulee",
-  parsnip = "stop_iter",
-  original = "stop_iter",
-  func = list(pkg = "dials", fun = "stop_iter"),
-  has_submodel = FALSE
-)
-
 set_fit(
   model = "multinom_reg",
   eng = "brulee",
