@@ -93,9 +93,9 @@ set_pred(
     # model mode
     pre = function(x, object) {
       if (object$fit$response != "continuous") {
-        rlang::abort(
-          glue::glue("`kknn` model does not appear to use numeric predictions.",
-                     " Was the model fit with a continuous response variable?")
+        cli::cli_abort(
+          c("`kknn` model does not appear to use numeric predictions.",
+            "i" = "Was the model fit with a continuous response variable?")
         )
       }
       x
@@ -136,9 +136,9 @@ set_pred(
   value = list(
     pre = function(x, object) {
       if (!(object$fit$response %in% c("ordinal", "nominal"))) {
-        rlang::abort(
-          glue::glue("`kknn` model does not appear to use class predictions.",
-                     " Was the model fit with a factor response variable?")
+        cli::cli_abort(
+          c("`kknn` model does not appear to use class predictions.",
+            "i" = "Was the model fit with a factor response variable?")
         )
       }
       x
@@ -162,9 +162,9 @@ set_pred(
   value = list(
     pre = function(x, object) {
       if (!(object$fit$response %in% c("ordinal", "nominal"))) {
-        rlang::abort(
-          glue::glue("`kknn` model does not appear to use class predictions.",
-                     " Was the model fit with a factor response variable?")
+        cli::cli_abort(
+          c("`kknn` model does not appear to use class predictions.",
+            "i" = "Was the model fit with a factor response variable?")
         )
       }
       x
