@@ -30,6 +30,10 @@ generics::augment
 #' @export
 generics::required_pkgs
 
+#' @importFrom hardhat contr_one_hot
+#' @export
+hardhat::contr_one_hot
+
 #' @importFrom hardhat extract_spec_parsnip
 #' @export
 hardhat::extract_spec_parsnip
@@ -58,3 +62,6 @@ hardhat::frequency_weights
 #' @export
 hardhat::importance_weights
 
+#' @importFrom hardhat extract_fit_time
+#' @export
+hardhat::extract_fit_time
