@@ -45,12 +45,12 @@ get_glmn_coefs <- function(x, penalty = 0.01) {
   res <- as.matrix(res)
   colnames(res) <- "estimate"
   rn <- rownames(res)
-  res <- tibble::as_tibble(res) %>% mutate(term = rn, penalty = penalty)
+  res <- tibble::as_tibble(res) |> mutate(term = rn, penalty = penalty)
   res <- dplyr::select(res, term, estimate, penalty)
   if (is.list(res$estimate)) {
     res$estimate <- purrr::map(
       res$estimate,
-      ~ as_tibble(as.matrix(.x), rownames = "term")
+      \(x) as_tibble(as.matrix(x), rownames = "term")
     )
     res <- tidyr::unnest(res, cols = c(estimate), names_repair = "minimal")
     names(res) <- c("class", "term", "estimate", "penalty")
